"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudWatchEnvelope = void 0;
const envelope_js_1 = require("./envelope.js");
const index_js_1 = require("../schemas/index.js");
const errors_js_1 = require("../errors.js");
/**
 * CloudWatch Envelope to extract a List of log records.
 *
 *  The record's body parameter is a string (after being base64 decoded and gzipped),
 *  though it can also be a JSON encoded string.
 *  Regardless of its type it'll be parsed into a BaseModel object.
 *
 *  Note: The record will be parsed the same way so if model is str
 */
class CloudWatchEnvelope extends envelope_js_1.Envelope {
    static parse(data, schema) {
        const parsedEnvelope = index_js_1.CloudWatchLogsSchema.parse(data);
        return parsedEnvelope.awslogs.data.logEvents.map((record) => {
            return super.parse(record.message, schema);
        });
    }
    static safeParse(data, schema) {
        const parsedEnvelope = index_js_1.CloudWatchLogsSchema.safeParse(data);
        if (!parsedEnvelope.success) {
            return {
                success: false,
                error: new errors_js_1.ParseError('Failed to parse CloudWatch envelope', parsedEnvelope.error),
                originalEvent: data,
            };
        }
        const parsedLogEvents = [];
        for (const record of parsedEnvelope.data.awslogs.data.logEvents) {
            const parsedMessage = super.safeParse(record.message, schema);
            if (!parsedMessage.success) {
                return {
                    success: false,
                    error: new errors_js_1.ParseError('Failed to parse CloudWatch log event', parsedMessage.error),
                    originalEvent: data,
                };
            }
            else {
                parsedLogEvents.push(parsedMessage.data);
            }
        }
        return {
            success: true,
            data: parsedLogEvents,
        };
    }
}
exports.CloudWatchEnvelope = CloudWatchEnvelope;
