import { z } from 'zod';
declare const APIGatewayProxyEventV2Schema: z.ZodObject<{
    version: z.ZodString;
    routeKey: z.ZodString;
    rawPath: z.ZodString;
    rawQueryString: z.ZodString;
    cookies: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    headers: z.ZodRecord<z.ZodString, z.ZodString>;
    queryStringParameters: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>;
    pathParameters: z.ZodOptional<z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>>;
    stageVariables: z.ZodOptional<z.ZodNullable<z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodString>>>>;
    requestContext: z.ZodObject<{
        accountId: z.ZodString;
        apiId: z.ZodString;
        authorizer: z.ZodOptional<z.ZodObject<{
            jwt: z.ZodOptional<z.ZodObject<{
                claims: z.ZodRecord<z.ZodString, z.ZodAny>;
                scopes: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
            }, "strip", z.ZodTypeAny, {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            }, {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            }>>;
            iam: z.ZodOptional<z.ZodObject<{
                accessKey: z.ZodOptional<z.ZodString>;
                accountId: z.ZodOptional<z.ZodString>;
                callerId: z.ZodOptional<z.ZodString>;
                principalOrgId: z.ZodOptional<z.ZodNullable<z.ZodString>>;
                userArn: z.ZodOptional<z.ZodString>;
                userId: z.ZodOptional<z.ZodString>;
                cognitoIdentity: z.ZodOptional<z.ZodNullable<z.ZodObject<{
                    amr: z.ZodArray<z.ZodString, "many">;
                    identityId: z.ZodString;
                    identityPoolId: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }, {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                }>>>;
            }, "strip", z.ZodTypeAny, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }, {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            }>>;
            lambda: z.ZodOptional<z.ZodRecord<z.ZodString, z.ZodAny>>;
        }, "strip", z.ZodTypeAny, {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        }, {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        }>>;
        authentication: z.ZodOptional<z.ZodNullable<z.ZodObject<{
            clientCert: z.ZodOptional<z.ZodObject<{
                clientCertPem: z.ZodString;
                subjectDN: z.ZodString;
                issuerDN: z.ZodString;
                serialNumber: z.ZodString;
                validity: z.ZodObject<{
                    notBefore: z.ZodString;
                    notAfter: z.ZodString;
                }, "strip", z.ZodTypeAny, {
                    notBefore: string;
                    notAfter: string;
                }, {
                    notBefore: string;
                    notAfter: string;
                }>;
            }, "strip", z.ZodTypeAny, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }, {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            }>>;
        }, "strip", z.ZodTypeAny, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }, {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        }>>>;
        domainName: z.ZodString;
        domainPrefix: z.ZodString;
        http: z.ZodObject<{
            method: z.ZodEnum<["GET", "POST", "PUT", "PATCH", "DELETE", "HEAD", "OPTIONS"]>;
            path: z.ZodString;
            protocol: z.ZodString;
            sourceIp: z.ZodString;
            userAgent: z.ZodString;
        }, "strip", z.ZodTypeAny, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }, {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        }>;
        requestId: z.ZodString;
        routeKey: z.ZodString;
        stage: z.ZodString;
        time: z.ZodString;
        timeEpoch: z.ZodNumber;
    }, "strip", z.ZodTypeAny, {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }, {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    }>;
    body: z.ZodOptional<z.ZodString>;
    isBase64Encoded: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    routeKey: string;
    version: string;
    headers: Record<string, string>;
    requestContext: {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    isBase64Encoded: boolean;
    rawPath: string;
    rawQueryString: string;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    body?: string | undefined;
    cookies?: string[] | undefined;
}, {
    routeKey: string;
    version: string;
    headers: Record<string, string>;
    requestContext: {
        accountId: string;
        apiId: string;
        stage: string;
        requestId: string;
        domainName: string;
        domainPrefix: string;
        routeKey: string;
        http: {
            path: string;
            sourceIp: string;
            userAgent: string;
            protocol: string;
            method: "GET" | "POST" | "PUT" | "PATCH" | "DELETE" | "HEAD" | "OPTIONS";
        };
        time: string;
        timeEpoch: number;
        authorizer?: {
            jwt?: {
                claims: Record<string, any>;
                scopes?: string[] | undefined;
            } | undefined;
            iam?: {
                accessKey?: string | undefined;
                accountId?: string | undefined;
                principalOrgId?: string | null | undefined;
                userArn?: string | undefined;
                callerId?: string | undefined;
                userId?: string | undefined;
                cognitoIdentity?: {
                    amr: string[];
                    identityId: string;
                    identityPoolId: string;
                } | null | undefined;
            } | undefined;
            lambda?: Record<string, any> | undefined;
        } | undefined;
        authentication?: {
            clientCert?: {
                clientCertPem: string;
                subjectDN: string;
                issuerDN: string;
                serialNumber: string;
                validity: {
                    notBefore: string;
                    notAfter: string;
                };
            } | undefined;
        } | null | undefined;
    };
    isBase64Encoded: boolean;
    rawPath: string;
    rawQueryString: string;
    queryStringParameters?: Record<string, string> | undefined;
    pathParameters?: Record<string, string> | null | undefined;
    stageVariables?: Record<string, string> | null | undefined;
    body?: string | undefined;
    cookies?: string[] | undefined;
}>;
export { APIGatewayProxyEventV2Schema };
//# sourceMappingURL=apigwv2.d.ts.map