"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CloudWatchLogEventSchema = exports.decompressRecordToJSON = exports.CloudWatchLogsDecodeSchema = exports.CloudWatchLogsSchema = void 0;
const zod_1 = require("zod");
const node_zlib_1 = require("node:zlib");
const CloudWatchLogEventSchema = zod_1.z.object({
    id: zod_1.z.string(),
    timestamp: zod_1.z.number(),
    message: zod_1.z.string(),
});
exports.CloudWatchLogEventSchema = CloudWatchLogEventSchema;
const CloudWatchLogsDecodeSchema = zod_1.z.object({
    messageType: zod_1.z.string(),
    owner: zod_1.z.string(),
    logGroup: zod_1.z.string(),
    logStream: zod_1.z.string(),
    subscriptionFilters: zod_1.z.array(zod_1.z.string()),
    logEvents: zod_1.z.array(CloudWatchLogEventSchema),
});
exports.CloudWatchLogsDecodeSchema = CloudWatchLogsDecodeSchema;
const decompressRecordToJSON = (data) => {
    const uncompressed = (0, node_zlib_1.gunzipSync)(Buffer.from(data, 'base64')).toString('utf8');
    return CloudWatchLogsDecodeSchema.parse(JSON.parse(uncompressed));
};
exports.decompressRecordToJSON = decompressRecordToJSON;
const CloudWatchLogsSchema = zod_1.z.object({
    awslogs: zod_1.z.object({
        data: zod_1.z.string().transform((data) => decompressRecordToJSON(data)),
    }),
});
exports.CloudWatchLogsSchema = CloudWatchLogsSchema;
