"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KafkaRecordSchema = exports.KafkaMskEventSchema = exports.KafkaSelfManagedEventSchema = void 0;
const zod_1 = require("zod");
const KafkaRecordSchema = zod_1.z.object({
    topic: zod_1.z.string(),
    partition: zod_1.z.number(),
    offset: zod_1.z.number(),
    timestamp: zod_1.z.number(),
    timestampType: zod_1.z.string(),
    key: zod_1.z.string().transform((key) => {
        return Buffer.from(key, 'base64').toString();
    }),
    value: zod_1.z.string().transform((value) => {
        return Buffer.from(value, 'base64').toString();
    }),
    headers: zod_1.z.array(zod_1.z.record(zod_1.z.string(), zod_1.z.array(zod_1.z.number()).transform((value) => {
        return String.fromCharCode(...value);
    }))),
});
exports.KafkaRecordSchema = KafkaRecordSchema;
const KafkaBaseEventSchema = zod_1.z.object({
    bootstrapServers: zod_1.z
        .string()
        .transform((bootstrapServers) => {
        return bootstrapServers ? bootstrapServers.split(',') : undefined;
    })
        .nullish(),
    records: zod_1.z.record(zod_1.z.string(), zod_1.z.array(KafkaRecordSchema)),
});
const KafkaSelfManagedEventSchema = KafkaBaseEventSchema.extend({
    eventSource: zod_1.z.literal('aws:SelfManagedKafka'),
});
exports.KafkaSelfManagedEventSchema = KafkaSelfManagedEventSchema;
const KafkaMskEventSchema = KafkaBaseEventSchema.extend({
    eventSource: zod_1.z.literal('aws:kafka'),
    eventSourceArn: zod_1.z.string(),
});
exports.KafkaMskEventSchema = KafkaMskEventSchema;
