"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.KinesisFirehoseSqsSchema = exports.KinesisFirehoseSchema = void 0;
const zod_1 = require("zod");
const sqs_js_1 = require("./sqs.js");
const KinesisRecordMetaData = zod_1.z.object({
    shardId: zod_1.z.string(),
    partitionKey: zod_1.z.string(),
    approximateArrivalTimestamp: zod_1.z.number().positive(),
    sequenceNumber: zod_1.z.string(),
    subsequenceNumber: zod_1.z.number(),
});
const KinesisFireHoseRecordBase = zod_1.z.object({
    recordId: zod_1.z.string(),
    approximateArrivalTimestamp: zod_1.z.number().positive(),
    kinesisRecordMetaData: KinesisRecordMetaData.optional(),
});
const KinesisFireHoseBaseSchema = zod_1.z.object({
    invocationId: zod_1.z.string(),
    deliveryStreamArn: zod_1.z.string(),
    region: zod_1.z.string(),
    sourceKinesisStreamArn: zod_1.z.string().optional(),
});
const KinesisFirehoseRecord = KinesisFireHoseRecordBase.extend({
    data: zod_1.z
        .string()
        .transform((data) => Buffer.from(data, 'base64').toString('utf8')),
});
const KinesisFirehoseSqsRecord = KinesisFireHoseRecordBase.extend({
    data: zod_1.z.string().transform((data) => {
        try {
            return sqs_js_1.SqsRecordSchema.parse(JSON.parse(Buffer.from(data, 'base64').toString('utf8')));
        }
        catch (e) {
            return data;
        }
    }),
});
const KinesisFirehoseSchema = KinesisFireHoseBaseSchema.extend({
    records: zod_1.z.array(KinesisFirehoseRecord),
});
exports.KinesisFirehoseSchema = KinesisFirehoseSchema;
const KinesisFirehoseSqsSchema = KinesisFireHoseBaseSchema.extend({
    records: zod_1.z.array(KinesisFirehoseSqsRecord),
});
exports.KinesisFirehoseSqsSchema = KinesisFirehoseSqsSchema;
